==> helm-annotations-2.9.0-sources.jar: io/dekorate/helm/config/ValueReferenceFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ValueReferenceFluentImpl<A extends io.dekorate.helm.config.ValueReferenceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.dekorate.helm.config.ValueReferenceFluent<A>{
  public ValueReferenceFluentImpl() {
  }
  public ValueReferenceFluentImpl(io.dekorate.helm.config.ValueReference instance) {
    this.withProperty(instance.getProperty()); 
    this.withJsonPaths(instance.getJsonPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
  }
  private java.lang.String property;
  private java.util.List<java.lang.String> jsonPaths = new java.util.ArrayList<java.lang.String>();
  private java.lang.String profile;
  private java.lang.String value;
  public java.lang.String getProperty() {
    return this.property;
  }
  public A withProperty(java.lang.String property) {
    this.property=property; return (A) this;
  }
  public java.lang.Boolean hasProperty() {
    return this.property != null;
  }
  
  /**
   * Method is deprecated. use withProperty instead.
   */
  @java.lang.Deprecated
  public A withNewProperty(java.lang.String arg0) {
    return (A)withProperty(new String(arg0));
  }
  public A withJsonPaths(java.lang.String... jsonPaths) {
    if (this.jsonPaths != null) {this.jsonPaths.clear();}
    if (jsonPaths != null) {for (java.lang.String item :jsonPaths){ this.addToJsonPaths(item);}} return (A) this;
  }
  public java.lang.String[] getJsonPaths() {
    //This needs to work with primitives, so we use arrays.
int size = jsonPaths != null ? jsonPaths.size() : 0;
java.lang.String[] result = new java.lang.String[size];
if (size == 0) {
   return result;
}
int index = 0;
for (java.lang.String item : jsonPaths) {
    result[index++]=item;
}
return result;

  }
  public A addToJsonPaths(java.lang.Integer index,java.lang.String item) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    this.jsonPaths.add(index, item);
    return (A)this;
  }
  public A setToJsonPaths(java.lang.Integer index,java.lang.String item) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    this.jsonPaths.set(index, item); return (A)this;
  }
  public A addToJsonPaths(java.lang.String... items) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.jsonPaths.add(item);} return (A)this;
  }
  public A addAllToJsonPaths(java.util.Collection<java.lang.String> items) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.jsonPaths.add(item);} return (A)this;
  }
  public A removeFromJsonPaths(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.jsonPaths!= null){ this.jsonPaths.remove(item);}} return (A)this;
  }
  public A removeAllFromJsonPaths(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.jsonPaths!= null){ this.jsonPaths.remove(item);}} return (A)this;
  }
  public java.lang.Boolean hasJsonPaths() {
    return jsonPaths != null && !jsonPaths.isEmpty();
  }
  public A addNewJsonPath(java.lang.String arg0) {
    return (A)addToJsonPaths(new String(arg0));
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public A withProfile(java.lang.String profile) {
    this.profile=profile; return (A) this;
  }
  public java.lang.Boolean hasProfile() {
    return this.profile != null;
  }
  
  /**
   * Method is deprecated. use withProfile instead.
   */
  @java.lang.Deprecated
  public A withNewProfile(java.lang.String arg0) {
    return (A)withProfile(new String(arg0));
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  
  /**
   * Method is deprecated. use withValue instead.
   */
  @java.lang.Deprecated
  public A withNewValue(java.lang.String arg0) {
    return (A)withValue(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValueReferenceFluentImpl that = (ValueReferenceFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (jsonPaths != null ? !jsonPaths.equals(that.jsonPaths) :that.jsonPaths != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  jsonPaths,  profile,  value,  super.hashCode());
  }
  
}

==> helm-annotations-2.9.2-sources.jar: io/dekorate/helm/config/ValueReferenceFluentImpl.java <==
package io.dekorate.helm.config;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ValueReferenceFluentImpl<A extends ValueReferenceFluent<A>> extends BaseFluent<A> implements ValueReferenceFluent<A>{
  public ValueReferenceFluentImpl() {
  }
  public ValueReferenceFluentImpl(io.dekorate.helm.config.ValueReference instance) {
    this.withProperty(instance.getProperty()); 
    this.withJsonPaths(instance.getJsonPaths()); 
    this.withProfile(instance.getProfile()); 
    this.withValue(instance.getValue()); 
  }
  private String property;
  private List<java.lang.String> jsonPaths = new ArrayList<java.lang.String>();
  private java.lang.String profile;
  private java.lang.String value;
  public java.lang.String getProperty() {
    return this.property;
  }
  public A withProperty(java.lang.String property) {
    this.property=property; return (A) this;
  }
  public Boolean hasProperty() {
    return this.property != null;
  }
  public A withJsonPaths(java.lang.String... jsonPaths) {
    if (this.jsonPaths != null) {this.jsonPaths.clear();}
    if (jsonPaths != null) {for (java.lang.String item :jsonPaths){ this.addToJsonPaths(item);}} return (A) this;
  }
  public java.lang.String[] getJsonPaths() {
    //This needs to work with primitives, so we use arrays.
int size = jsonPaths != null ? jsonPaths.size() : 0;
java.lang.String[] result = new java.lang.String[size];
if (size == 0) {
   return result;
}
int index = 0;
for (java.lang.String item : jsonPaths) {
    result[index++]=item;
}
return result;

  }
  public A addToJsonPaths(Integer index,java.lang.String item) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    this.jsonPaths.add(index, item);
    return (A)this;
  }
  public A setToJsonPaths(java.lang.Integer index,java.lang.String item) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    this.jsonPaths.set(index, item); return (A)this;
  }
  public A addToJsonPaths(java.lang.String... items) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.jsonPaths.add(item);} return (A)this;
  }
  public A addAllToJsonPaths(Collection<java.lang.String> items) {
    if (this.jsonPaths == null) {this.jsonPaths = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.jsonPaths.add(item);} return (A)this;
  }
  public A removeFromJsonPaths(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.jsonPaths!= null){ this.jsonPaths.remove(item);}} return (A)this;
  }
  public A removeAllFromJsonPaths(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.jsonPaths!= null){ this.jsonPaths.remove(item);}} return (A)this;
  }
  public java.lang.Boolean hasJsonPaths() {
    return jsonPaths != null && !jsonPaths.isEmpty();
  }
  public java.lang.String getProfile() {
    return this.profile;
  }
  public A withProfile(java.lang.String profile) {
    this.profile=profile; return (A) this;
  }
  public java.lang.Boolean hasProfile() {
    return this.profile != null;
  }
  public java.lang.String getValue() {
    return this.value;
  }
  public A withValue(java.lang.String value) {
    this.value=value; return (A) this;
  }
  public java.lang.Boolean hasValue() {
    return this.value != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ValueReferenceFluentImpl that = (ValueReferenceFluentImpl) o;
    if (property != null ? !property.equals(that.property) :that.property != null) return false;
    if (jsonPaths != null ? !jsonPaths.equals(that.jsonPaths) :that.jsonPaths != null) return false;
    if (profile != null ? !profile.equals(that.profile) :that.profile != null) return false;
    if (value != null ? !value.equals(that.value) :that.value != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  jsonPaths,  profile,  value,  super.hashCode());
  }
  public java.lang.String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (property != null) { sb.append("property:"); sb.append(property + ","); }
    if (jsonPaths != null && !jsonPaths.isEmpty()) { sb.append("jsonPaths:"); sb.append(jsonPaths + ","); }
    if (profile != null) { sb.append("profile:"); sb.append(profile + ","); }
    if (value != null) { sb.append("value:"); sb.append(value); }
    sb.append("}");
    return sb.toString();
  }
  
}
